Learn R Programming

hgm (version 1.11)

hgm-package: HGM

Description

The holonomic gradient method (HGM, hgm) gives a way to evaluate normalizing constants of unnormalized probability distributions by utilizing holonomic systems of differential or difference equations. The holonomic gradient descent (HGD, hgd) gives a method to find maximal likelihood estimates by utilizing the HGM.

Arguments

Details

Package:
hgm
Type:
Package
License:
GPL-2
LazyLoad:
yes
The HGM and HGD are proposed in the paper below. This method based on the fact that a broad class of normalizing constants of unnormalized probability distributions belongs to the class of holonomic functions, which are solutions of holonomic systems of linear partial differential equations.

References

See Also

hgm.ncBingham, hgm.ncorthant, hgm.ncso3, hgm.pwishart, hgm.Rhgm

Examples

Run this code
## Not run: 
# example(hgm.ncBingham)
# example(hgm.ncorthant)
# example(hgm.ncso3)
# example(hgm.pwishart)
# example(hgm.Rhgm)
# ## End(Not run)

Run the code above in your browser using DataLab