hgm.Rhgm.demo1:
The function hgm.Rhgm.demo1 performs a demonstration of the function
hgm.Rhgm.
Description
The function hgm.Rhgm.demo1 performs a demonstration of the function
hgm.Rhgm.
Value
The returned value is a dataframe.
The column exact of the dataframe is the exact value of the normalizing
constant. The column byHGM is the value obtained by the HGM.
The column start is the initial value for the HGM.
Details
The function hgm.Rhgm.demo1 evaluates the normalizing constant
of the Von-Mises distribution by the HGM.