Learn R Programming

hgm (version 1.11)

hgm.ncorthant: The function hgm.ncorthant evaluates the orthant probability.

Description

The function hgm.ncorthant evaluates the orthant probability, which is the normalization constant of the multivariate normal distribution restrcted to the first orthant.

Usage

hgm.ncorthant(x,y,rk_step_size=1e-3)

Arguments

x
See the description of y.
y
This function evaluates the orthant probability for the m dimensional multivariate normal distribution whose m by m covariance matrix and the mean vector of size m are x and y respectively.
rk_step_size
The step size for the Runge-Kutta method to apply the HGM.

Value

The output is the orthant probalibity.

Details

The function hgm.ncorthant evaluates the orthant probability, which is the normalization constant of the m-dimensional multivariate normal distribution restrcted to the first orthant. It uses the holonomic gradient method (HGM) to evalute it. The rank of the system of differential equations for the HGM is 2^m.

References

Tamio Koyama, Akimichi Takemura, Calculation of orthant probabilities by the holonomic gradient method, http://arxiv.org/abs/1211.6822.

Examples

Run this code
## =====================================================
## Example 1. Computing the orthant probability
## =====================================================
x <- matrix(c(15,26,23,19,
	      26,47,46,35,
	      23,46,65,38,
	      19,35,38,33), nrow =4) 
y <- c(1,2,3,4)
hgm.ncorthant(x,y)

Run the code above in your browser using DataLab