The holonomic gradient method (HGM, hgm) gives a way to evaluate normalizing
constants of unnormalized probability distributions by utilizing holonomic
systems of differential or difference equations.
The holonomic gradient descent (HGD, hgd) gives a method
to find maximal likelihood estimates by utilizing the HGM.
Arguments
Details
ll{
Package: hgm
Type: Package
License: GPL-2
LazyLoad: yes
}
The HGM and HGD are proposed in the paper below.
This method based on the fact that a broad class of normalizing constants
of unnormalized probability distributions belongs to the class of
holonomic functions, which are solutions of holonomic systems of linear
partial differential equations.
References
[N3OST2] Hiromasa Nakayama, Kenta Nishiyama, Masayuki Noro, Katsuyoshi Ohara,
Tomonari Sei, Nobuki Takayama, Akimichi Takemura,
Holonomic Gradient Descent and its Application to Fisher-Bingham Integral,
Advances in Applied Mathematics 47 (2011), 639--658,http://dx.doi.org/10.1016/j.aam.2011.03.001
[dojo] Edited by T.Hibi, Groebner Bases: Statistics and Software Systems, Springer, 2013,http://dx.doi.org/10.1007/978-4-431-54574-3