Usage
hgm.pwishart(m,n,beta,q0,approxdeg,h,dp,q,mode,method, err,automatic,assigned_series_error,verbose)
Arguments
m
The dimension of the Wishart matrix.
n
The degree of freedome (a parameter of the Wishart distribution)
beta
The eigenvalues of the inverse of the covariant matrix /2
(a parameter of the Wishart distribution).
The beta is equal to inverse(sigma)/2.
q0
The point to evaluate the matrix hypergeometric series. q0>0
approxdeg
Zonal polynomials upto the approxdeg are calculated to evaluate
values near the origin. A zonal polynomial is determined by a given
partition (k1,...,km). We call the sum k1+...+km the degree.
h
A (small) step size for the Runge-Kutta method. h>0.
dp
Sampling interval of solutions by the Runge-Kutta method.
q
The second value y[0] of this function is the Prob(L1 < q)
where L1 is the first eigenvalue of the Wishart matrix.
mode
When mode=c(1,0,0), it returns the evaluation
of the matrix hypergeometric series and its derivatives at x0.
When mode=c(1,1,(m^2+1)*p), intermediate values of P(L1 < x) with respect to
p-steps of x are also returned. Sampling interval is controled by dp.
method
a-rk4 is the default value.
When method="a-rk4", the adaptive Runge-Kutta method is used.
Steps are automatically adjusted by err.
err
When err=c(e1,e2), e1 is the absolute error and e2 is the relative error.
As long as NaN is not returned, it is recommended to set to
err=c(0.0, 1e-10), because initial values are usually very small.
automatic
automatic=1 is the default value.
If it is 1, the degree of the series approximation will be increased until
|(F(i)-F(i-1))/F(i-1)| < assigned_series_error where
F(i) is the degree i approximation of the hypergeometric series
with matrix argument.
Step sizes for the Runge-Kutta method are also set automatically from
the assigned_series_error if it is 1.
assigned_series_error
assigned_series_error=0.00001 is the default value.
verbose
verbose=0 is the default value.
If it is 1, then steps of automatic degree updates and several parameters
are output to stdout and stderr.